==> mstflint_4.16.0+1.orig.tar.gz: mstflint-4.16.0/mlxfwupdate/psid_query_item.h <==

/*
 * Copyright (C) Jan 2006 Mellanox Technologies Ltd. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

#ifndef __PSID_QUERY_ITEM_H__
#define __PSID_QUERY_ITEM_H__

#include <img_version.h>
#include <string>
#include <vector>

using namespace std;

class PsidQueryItem {
public:

    PsidQueryItem() : devId(0), revId(0), found(0), isFailSafe(true) {};
    virtual ~PsidQueryItem()
    {
    }
    const ImgVersion* findImageVersion(string type);
    string psid;
    string url;
    string pns;
    string board_rev;
    string selector_tag;
    string description;
    string name;
    int devId;
    int revId;
    string iniName;
    string release_note;
    int found;
    string type;
    vector<ImgVersion> imgVers;
    bool isFailSafe;
    string branch;
};

#endif

==> mstflint_4.31.0+1.orig.tar.gz: mstflint-4.31.0/mlxfwupdate/psid_query_item.h <==

/*
 * Copyright (C) Jan 2006 Mellanox Technologies Ltd. All rights reserved.
 * Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

#ifndef __PSID_QUERY_ITEM_H__
#define __PSID_QUERY_ITEM_H__

#include <img_version.h>
#include <string>
#include <vector>

using namespace std;

class PsidQueryItem
{
public:
    PsidQueryItem() : devId(0), revId(0), found(0), isFailSafe(true){};
    virtual ~PsidQueryItem() {}
    const ImgVersion* findImageVersion(string type);
    string psid;
    string url;
    string pns;
    string board_rev;
    string selector_tag;
    string description;
    string name;
    int devId;
    int revId;
    string iniName;
    string release_note;
    int found;
    string type;
    vector<ImgVersion> imgVers;
    bool isFailSafe;
    string branch;
};

#endif
